@@ -14,14 +14,14 @@
  * The format is oldest API compatible release - ABI compat number.
  * The compatibility number allows pre-release ABI to be versioned.
  */
-#define UHD_VERSION_ABI_STRING "3.13.0"
+#define UHD_VERSION_ABI_STRING "3.15.0"
 
 /*!
  * A macro to check UHD version at compile-time.
  * The value of this macro is MAJOR * 1000000 + API * 10000 + ABI * 100 + PATCH
  * (e.g., for UHD 3.10.0.1 this is 3100001).
  */
-#define UHD_VERSION 3130001
+#define UHD_VERSION 3150000
 
 #ifdef __cplusplus
 #include <uhd/config.hpp>
@@ -35,6 +35,9 @@ namespace uhd{
     //! Get the ABI compatibility string for this build of the library
     UHD_API std::string get_abi_string(void);
 
+    //! Get the component string
+    UHD_API std::string get_component(void);
+
 } //namespace uhd
 #endif
 
